@@ -23,7 +23,6 @@
 #define __VOLK_ATTR_IMPORT __declspec(dllimport)
 #define __VOLK_PREFETCH(addr)
 #define __VOLK_ASM __asm
-#define __VOLK_VOLATILE
 #elif defined(__clang__)
 // AppleClang also defines __GNUC__, so do this check first.  These
 // will probably be the same as for __GNUC__, but let's keep them
@@ -33,7 +32,6 @@
 #define __VOLK_ATTR_INLINE __attribute__((always_inline))
 #define __VOLK_ATTR_DEPRECATED __attribute__((deprecated))
 #define __VOLK_ASM __asm__
-#define __VOLK_VOLATILE __volatile__
 #define __VOLK_ATTR_EXPORT __attribute__((visibility("default")))
 #define __VOLK_ATTR_IMPORT __attribute__((visibility("default")))
 #define __VOLK_PREFETCH(addr) __builtin_prefetch(addr)
@@ -43,7 +41,6 @@
 #define __VOLK_ATTR_INLINE __attribute__((always_inline))
 #define __VOLK_ATTR_DEPRECATED __attribute__((deprecated))
 #define __VOLK_ASM __asm__
-#define __VOLK_VOLATILE __volatile__
 #if __GNUC__ >= 4
 #define __VOLK_ATTR_EXPORT __attribute__((visibility("default")))
 #define __VOLK_ATTR_IMPORT __attribute__((visibility("default")))
@@ -61,7 +58,6 @@
 #define __VOLK_ATTR_IMPORT __declspec(dllimport)
 #define __VOLK_PREFETCH(addr)
 #define __VOLK_ASM __asm
-#define __VOLK_VOLATILE
 #else
 #define __VOLK_ATTR_ALIGNED(x)
 #define __VOLK_ATTR_UNUSED
@@ -71,7 +67,6 @@
 #define __VOLK_ATTR_IMPORT
 #define __VOLK_PREFETCH(addr)
 #define __VOLK_ASM __asm__
-#define __VOLK_VOLATILE __volatile__
 #endif
 
 ////////////////////////////////////////////////////////////////////////
